package physbeans.editors;

import java.beans.*;
import physbeans.model.*;

/**
 * Property editor for a ComplexToRealEnum value using a dropdown list.
 */
public class ComplexToRealEnumEditor extends PropertyEditorSupport {

  private String[] types;

  public ComplexToRealEnumEditor() {
    ComplexToRealEnum[] values = ComplexToRealEnum.values();
    types = new String[values.length];
    for (int i = 0; i < values.length; i++) {
      types[i] = values[i].getName();
    }
  }

  /**
   * Returns a list of tags for the drop down list.
   */
  public String[] getTags() {
    return types;
  }

  /**
   * Returns a string that represents the current property.
   */
  public String getAsText() {
    return ((ComplexToRealEnum) getValue()).getName();
  }

  /**
   * Reads the value of the property by parsing a string.
   */
  public void setAsText(String text) {
    ComplexToRealEnum[] values = ComplexToRealEnum.values();
    for (int i = 0; i < values.length; i++) {
      if (values[i].getName().equals(text)) {
        setValue(values[i]);
        return;
      }
    }
  }

  /**
   * Returns a string with java code that initializes the property.
   */
  public String getJavaInitializationString() {
    return "ComplexToRealEnum." + ((ComplexToRealEnum) getValue()).toString();
  }

  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return false;
  }
}
