package physbeans.editors;

import java.beans.*;

/**
 * Base class of property editors using a dropdown list.
 * <p>Children only have to define the types array in the constructor.
 */
public class TaggedEditor extends PropertyEditorSupport {
  
  protected String[] types;
  
  /**
   * Returns a list of tags for the drop down list.
   */
  public String[] getTags() {
    return types;
  }
  
  /**
   * Returns a string that represents the current property.
   */
  public String getAsText() {
    int value = ((Integer) getValue()).intValue();
    return types[value];
  }
  
  /**
   * Reads the value of the property by parsing a string.
   */
  public void setAsText(String s) {
    for (int i=0; i < types.length; i++) {
      if (types[i].equals(s)) {
        setValue(new Integer(i));
        return;
      }
    }
  }
  
  /**
   * Returns a string with java code that initializes the property.
   */
  public String getJavaInitializationString() {
    int value = ((Integer) getValue()).intValue();
    return "" +  value;
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return false;
  }
}
