package physbeans.event;

import java.util.*;

/**
 * Event to tell that one of a set of switches has changed state
 */
public class SwitchEvent extends EventObject {

  /** number of the switch */
  protected int number;
  /** new state of switch */
  protected boolean state;
  /** is true if only one of the switches can be on (radio buttons) */
  protected boolean exclusive;

  /**
   * constructor using the event source
   */
  public SwitchEvent(Object source) {
    this(source, 0, true, false);
  }

  /**
   * constructor for non-Radio switches, using the event source and the values to pass
   */
  public SwitchEvent(Object source, int number, boolean state) {
    this(source, number, state, false);
  }

  /**
   * general constructor using the event source and all values to pass
   */
  public SwitchEvent(Object source, int number, boolean state, boolean exclusive) {
    super(source);
    this.number = number;
    this.state = state;
    this.exclusive = exclusive;
  }

  /**
   * return the number of the switch
   */
  public int getValue() {
    return number;
  }

  /**
   * return the new state of the switch
   */
  public boolean getState() {
    return state;
  }

  /**
   * return the exclusive flag of the switch
   */
  public boolean isExclusive() {
    return exclusive;
  }
}
