package physbeans.event;

import java.util.*;

/**
 * class to simplify use of TriggerEvents
 */
public class TriggerSupport {
  
  /** list of all observer objects listening  */
  protected Vector<TriggerListener> listeners;
  
  /** Creates a new instance of TriggerSupport */
  public TriggerSupport() {
    // prepare for listeners
    listeners = new Vector<TriggerListener>();
  }
  
  /**
   * register a TriggerListener
   */
  public synchronized void addTriggerListener(TriggerListener sl) {
    listeners.addElement(sl);
  }
  
  /**
   * de-register a TriggerListener
   */
  public synchronized void removeTriggerListener(TriggerListener sl) {
    listeners.removeElement(sl);
  }
  
  /**
   * inform all TriggerListeners that the value of the vector has changed
   */
  public void fireTriggerEvent(TriggerEvent e) {
    Vector l;
    
    // clone the list of listeners so that delivery and simultaneous
    // addition/deletion of listeners don't interfere
    synchronized (this) {
      l = (Vector) listeners.clone();
    }
    
    for (int i = 0; i < l.size(); i++) {
      ((TriggerListener) l.elementAt(i)).sourceChanged(e);
    }
  }
}
