package physbeans.event;

import java.util.*;
import physbeans.math.*;

/**
 * Event to tell that one or more vectors have changed.<br>
 * Vector means DVector or array of doubles.
 */
public class VectorEvent extends EventObject {
  
  /** the values to pass */
  protected DVector[] vecs;
  
  /**
   * constructor using the event source
   */
  public VectorEvent(Object source) {
    super(source);
  }
  
  /**
   * Constructor using an array of doubles to create an event with one DVector
   */
  public VectorEvent(Object source, double[] vals) {
    super(source);
    vecs = new DVector[1];
    vecs[0] = new DVector(vals);
  }
  
  /**
   * constructor using the event source and the values as DVector
   */
  public VectorEvent(Object source, DVector v) {
    super(source);
    vecs = new DVector[1];
    vecs[0] = v;
  }
  
  /**
   * Constructor using the event source and an array of DVector's
   */
  public VectorEvent(Object source, DVector[] v) {
    super(source);
    vecs = v;
  }
  
  /**
   * return the array values of the first (usually only) DVector
   */
  public double[] getValue() {
    return vecs[0].getArray();
  }
  
  /**
   * returns the first (usually only) vector
   */
  public DVector getVector() {
    return vecs[0];
  }
  
  /**
   * returns the vectors
   */
  public DVector[] getVectors() {
    return vecs;
  }
}
