package physbeans.func;

import java.io.*;
import physbeans.math.*;

/**
 * computes length and angle of a 2d vector
 */
public class Cart2PolarFunction extends GenericNdFunction implements Serializable {
  
  /**
   * constructs a standard function with 2 inputs and 2 outputs
   */
  public Cart2PolarFunction() {
    super(2, 2);
  }
  
  /**
   * Computes length and angle of a 2d vector.
   */
  protected DVector computeFunction(DVector in) {
    DVector out = new DVector(2);
    
    double x = in.get(0);
    double y = in.get(1);
    
    out.set(0, Math.hypot(x, y));
    out.set(1, Math.atan2(y, x));
    
    return out;
  }
  
  // conveniance functions to simplify event routing
  public double getR() {
    return getOutputValues(0);
  }
  public double getPhi() {
    return getOutputValues(1);
  }
  public void setX(double val) {
    setInputValues(0, val);
  }
  public void setY(double val) {
    setInputValues(1, val);
  }
}
