package physbeans.func;

import physbeans.model.*;
import physbeans.math.*;

/**
 * Combines several (scalar) OneParameterFunctions to one vector function.
 */
public class CombineScalarsFunction extends Generic1dFunction {
  
  protected Real1DFunction[] function;
  
  /**
   * Creates a new instance of CombineScalarsFunction.
   */
  public CombineScalarsFunction() {
    super();
    function = new Real1DFunction[3];
  }
  
  /**
   * Gets number of vector components.
   */
  public int getSize() {
    return function.length;
  }
  
  /**
   * Sets number of vector components.
   */
  public void setSize(int n) {
    function = new Real1DFunction[n];
    inform();
  }
  
  public DVector computeFunction(double t) {
    int n = function.length;
    DVector result = new DVector(n);
    for (int i = 0; i < n; i++) {
      if (function[i] != null) {
        result.set(i, function[i].evaluate(t));
      }
    }
    return result;
  }
  
  /**
   * Adds a OneParameterFunction at position i.
   */
  public void addFunction(int i, Real1DFunction f) {
    function[i] = f;
    inform();
  }
}
