package physbeans.func;

import java.io.*;
import physbeans.event.*;
import physbeans.math.*;

/**
 * Splits a vector input into several scalar outputs.<br>
 */
public class Demultiplexer extends GenericNdFunction implements Serializable {
  
  /** Creates a new instance of Demultiplexer */
  public Demultiplexer() {
    this(2);  // merge two scalars
  }
  
  /**
   *  Creates a Demultiplexer with n scalar inputs.
   */
  public Demultiplexer(int nIn) {
    // uses the generic input vector for the scalar values
    super(nIn, nIn);
  }
  
  /**
   * Computes new values for output vector.
   */
  protected DVector computeFunction(DVector in) {
    // simply propagates values to the output vector
    return in.copy();
  }
  
  /**
   * Propagates input values
   */
  public void trigger() {
    compute();  // compute new output values
    fireVectorEvent(new VectorEvent(this, outputValues)); // inform listeners
  }
  
  /**
   * Sets the number of input values.
   */
  public void setInputLength(int size) {
    inputValues = new DVector(size);
    setOutputLength(size);
  }
  
  /**
   * Sets new input value.<br>
   * If autotrigger is true (default), it triggers immediately when a new input
   * vector arrives.
   */
  public void setInputValues(int index, double val) {
    inputValues.set(index, val);
    
    if (autoTriggered) {
      trigger();
    }
  }
}
