package physbeans.func;

import physbeans.math.*;
import static physbeans.math.SpecialPolynomials.*;

/**
 * Applies a hermitian polynomial to its input value.
 */
public class HermitePolynomial extends OneParameterFunction {

  protected int n;

  public HermitePolynomial() {
    super();
    n = 0;
  }

  /**
   * Gets the order n of the Hermite polynomial.
   */
  public int getOrder() {
    return this.n;
  }

  /**
   * Sets the order n of the Hermite polynomial.
   */
  public void setOrder(int n) throws IllegalArgumentException {
    if (n < 0) {
      throw new IllegalArgumentException();
    }
    this.n = n;
    inform();
  }

  /**
   * Computes the hermite polynomial for one given value x.
   */
  public double evaluate(double x) {
    return H(n, x);
  }

  /**
   * Gets the coefficients of the polynomial.
   */
  public DVector getCoeff() {
    return Hcoeff(n);
  }

  /**
   * Returns the polynomial as string.
   */
  public String toString() {
    Polynomial p = new Polynomial(getCoeff());
    p.setPrecision(-1);
    return p.toString();
  }
}
