package physbeans.func;

import physbeans.math.*;
import physbeans.model.*;

/**
 * Function that computes a polynomial fitting a number of points.<br>
 * Input:<br>
 *    x    (x coordinates of points)<br>
 *    y    (y coordinates of points)<br>
 * Output:<br>
 *  poly     (coefficients of fit polynomial)
 */
public class PolynomialFitFunction extends GenericVectorFunction {
  
  protected int degree;
  
  /** Creates a default PolynomialFitFunction of degree 0. */
  public PolynomialFitFunction() {
    super(2, 1, 3);
    degree = 3;
  }
  
  /**
   * Computes new values for output vector.
   */
  protected void compute() {
    // degree must be larger than the number of points
    try {
      outputValues[0] = Polynomial.computeFitPolynomial(inputValues[0],
          inputValues[1], degree).getCoeff();
    } catch (RuntimeException e) {
      // points lead to singular matrix
      outputValues[0] = new DVector(0); // empty !
    }
  }
  
  /**
   * Gets degree of fit polynomial.
   */
  public int getDegree() {
    return degree;
  }
  
  /**
   * Sets degree of fit polynomial.
   */
  public void setDegree(int d) {
    degree = d;
    trigger();
  }
  
  /**
   * Sets x coordinates of input values.
   */
  public void setXCoordinates(DVector v) {
    setInputVector(0, v);
  }
  
  /**
   * Sets y coordinates of input values.
   */
  public void setYCoordinates(DVector v) {
    setInputVector(1, v);
  }
  
  /**
   * Sets x and y coordinates of the data points.
   */
  public void setPoints(Point2dVector p) {
    setInputVector(0, p.getXCoords());
    setInputVector(1, p.getYCoords());
  }
  
  /**
   * Gets output as polynomial.
   */
  public Polynomial getPolynomial() {
    return new Polynomial(getOutputVector());
  }
}
