package physbeans.func;

import physbeans.math.*;

/**
 * Function that selects some of the input signals and reorders them.<br>
 * Used mainly as interface between blocks that use different vector lengths.
 */
public class Selector extends GenericNdFunction {
  
  // correspondence between input and output
  protected int[] index;
  
  /**
   * standard selector: 2 inputs, one output
   */
  public Selector() {
    this(2,1);
  }
  
  /**
   * create Selector with in inputs and out outputs.<br>
   * default: connect the first input values to the output
   */
  public Selector(int in, int out) {
    super(in, out);
    index = new int[out];
    
    // default: connect first input lines to output
    for (int i=0; i < Math.min(in, out); i++) {
      index[i] = i;
    }
  }
  
  /**
   * gets array of index values.<br>
   * index[i] = j   <=> input j is connected to output i
   */
  public int[] getIndex() {
    return this.index;
  }
  
  /**
   * sets array of index values.<br>
   * index[i] = j   <=> input j is connected to output i
   * <p>Entries -1 indicate constant elements of the output vector.
   */
  public void setIndex(int[] index) {
    this.index = index;
  }
  
  /**
   * Copies selected values from in to out.
   */
  protected DVector computeFunction(DVector in) {
    for (int i = 0; i < index.length; i++) {
      if (index[i] >= 0) {
        outputValues.set(i, in.get(index[i]));
      }
    }
    return outputValues;
  }
  
}
