package physbeans.inout;

import javax.swing.*;

/**
 * output panel for display of texts or variables in text form
 */
public class Message extends PhysicsPanel {

  protected JLabel descriptionLabel;
  protected JTextArea messageArea;
  protected int separation;
  /** number of rows of text area */
  protected int rows;
  /** number of columns of text area */
  protected int cols;

  /**
   * creates a Message with standard description and message text
   */
  public Message() {
    this("Description:", "Message");
  }

  /**
   * creates a Message with given description and message text
   */
  public Message(String desc, String mess) {
    super();
    setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
    separation = 10;
    rows = 2;
    cols = 20;

    // setup description label
    descriptionLabel = new JLabel(desc, JLabel.RIGHT);
    descriptionLabel.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, separation));

    // setup message area
    messageArea = new JTextArea(rows, cols);
    messageArea.setEditable(false);
    messageArea.setLineWrap(true);
    messageArea.setWrapStyleWord(true);
    JScrollPane scrollPane = new JScrollPane(messageArea,
            JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
            JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);

    // build GUI
    add(descriptionLabel);
    add(scrollPane);
  }

  /**
   * gets description of the message
   */
  public String getDescription() {
    return descriptionLabel.getText();
  }

  /**
   * sets description of the message
   */
  public void setDescription(String desc) {
    descriptionLabel.setText(desc);
    repaint();
  }

  /**
   * gets message text
   */
  public String getMessage() {
    return messageArea.getText();
  }

  /**
   * sets message text
   */
  public void setMessage(String mess) {
    messageArea.setText(mess);
    repaint();
  }

  /**
   * gets separation of description and message labels
   */
  public int getSeparation() {
    return separation;
  }

  /**
   * sets separation of description and message labels
   */
  public void setSeparation(int sep) {
    separation = sep;
    descriptionLabel.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, sep));
    repaint();
  }

  /**
   * gets number of rows of text area
   */
  public int getRows() {
    return this.rows;
  }

  /**
   * sets number of rows of text area
   */
  public void setRows(int rows) {
    this.rows = rows;
    messageArea.setRows(rows);
    repaint();
  }

  /**
   * gets number of columns of text area
   */
  public int getColumns() {
    return this.cols;
  }

  /**
   * sets number of columns of text area
   */
  public void setColumns(int cols) {
    this.cols = cols;
    messageArea.setColumns(cols);
    repaint();
  }

  /**
   * Gets editable status of text area
   */
  public boolean isEditable() {
    return messageArea.isEditable();
  }

  /**
   * Sets editable status of text area
   */
  public void setEditable(boolean flag) {
    messageArea.setEditable(flag);
  }

  public void doLayout() {
    // AFTER definition of text or setting of value
    // best at layout time so that a font is already defined from the parent
    super.doLayout();
    descriptionLabel.setFont(null);
    messageArea.setFont(null);
  }
}
