package physbeans.math;

import physbeans.model.*;

/**
 * A LinearInterpolator linearly interpolates values between a series of
 * 2-dimensional points.
 */
public class LinearInterpolator extends Interpolator1D {
  
  /** 
   * Creates a new instance of LinearInterpolator 
   */
  public LinearInterpolator(Point2dVector pts) throws IllegalArgumentException {
    super(pts);
    checkOrder();
  }
  
  public double evaluate(double x) {
    int i = findIndex(x);
    
    // don't extrapolate, simply return NaN
    // TODO: linear extrapolation or clamping
    if (i < 0 || i >= points.size()) {
      return Double.NaN;
    }
    double x1 = points.getX(i);
    double x2 = points.getX(i+1);
    double y1 = points.getY(i);
    double y2 = points.getY(i+1);
    
    return (x - x1)*(y2 - y1)/(x2 - x1) + y1;
  }
  
}
