package physbeans.math;

/**
 * class to model ordinary differential equations<br>
 * x' = f(x, t), x(t0) = x0<br>
 * in d dimensions.
 */
public abstract class ODE {
  
  protected double t0;
  protected DVector x0;
  
  /**
   * Constructs an ODE with given initial conditions.
   */
  public ODE(DVector x0, double t0) {
    this.t0 = t0;
    this.x0 = x0.copy();
  }
  
  /**
   * Defines the right hand side giving the ODE x' = f(x, t).
   */
  public abstract DVector f(DVector x, double t);
  
  /**
   * Sets the initial time.
   */
  public void setT0(double t) {
    t0 = t;
  }
  
  /**
   * Gets the initial time.
   */
  public double getT0() {
    return t0;
  }
  
  /**
   * Sets the initial values (at the initial time).
   */
  public void setX0(DVector x) {
    x0 = x.copy();
  }
  
  /**
   * Gets the initial values (at the initial time).
   */
  public DVector getX0() {
    return x0.copy();
  }
  
  /**
   * Sets the component n of the initial values to val.<br>
   * Conveniance function to simplify event routing.
   */
  public void setX0(int n, double val) {
    x0.set(n, val);
  }
}
