package physbeans.model;

import physbeans.math.*;

/**
 * 2d grid of double values.<br>
 * Has a boundary with symmetric width in x resp. y direction.<br>
 * Its position is defined by world coordinates of the corners.
 */
public interface GridWithBoundary {
  
  /**
   * Gets the grid with all values (including boundary values).
   */
  public double[][] getGrid();
  
  /**
   * Gets total grid size in x direction in pixel.
   */
  public int getGridSizeX();
  
  /**
   * Gets total grid size in y direction in pixel.
   */
  public int getGridSizeY();
  
  /**
   * Gets number of boundary rows (on one side).
   */
  public int getBoundaryWidthX();
  
  /**
   * Gets number of boundary columns (on one side).
   */
  public int getBoundaryWidthY();
  
  /**
   * Gets the world coordinates of the lower left edge.
   */
  public DVector getMinWorld();
  
  /**
   * Gets the world coordinates of the upper right edge.
   */
  public DVector getMaxWorld();
   
}
