package physbeans.phys;

import java.io.*;

/**
 * Enumeration type for the kind of a thermodynamic state variable.
 * Possible values: P, V, T
 */
public class ThermodynamicStateVariable implements Serializable {
  
  /**
   * list of predefined values
   */
  public static ThermodynamicStateVariable P = new ThermodynamicStateVariable("p");
  public static ThermodynamicStateVariable V = new ThermodynamicStateVariable("V");
  public static ThermodynamicStateVariable T = new ThermodynamicStateVariable("T");
  
  protected static ThermodynamicStateVariable[] list = {P, V, T};
  
  private String name;
  
  /**
   * Creates a new instance of ThermodynamicStateVariable with a given String.
   * Since it is private, only the predefined values can be used.
   */
  private ThermodynamicStateVariable(String s) {
    name = s;
  }
  
  public String toString() {
    return name;
  }
  
  /**
   * Gets a list of all possible values.
   */
  public static ThermodynamicStateVariable[] getThermodynamicStateVariables() {
    return list;
  }
  
  /**
   * Gets a list of all possible values as strings.<br>
   * The order of the string list is the same as that of the type list.
   */
  public static String[] getStrings() {
    String[] stringList = new String[list.length];
    for (int i = 0; i < list.length; i++) {
      stringList[i] = list[i].toString();
    }
    
    return stringList;
  }
  
  /*
   * Gets a ThermodynamicStateVariable from its string.
   */
  public static ThermodynamicStateVariable createFromString(String s) {
    for (int i=0; i < list.length; i++) {
      if (list[i].toString().equals(s)) {
        return list[i];
      }
    }
    
    throw new IllegalArgumentException("illegal value " + s + " for thermodynamic state variable");
  }
  
  /**
   * Serialisation is not automatic for static objects.
   * It has to be augmented with writeObject and readObject.
   */
  private void writeObject(ObjectOutputStream out) throws IOException {
    out.defaultWriteObject();
    out.writeObject(P);
    out.writeObject(V);
    out.writeObject(T);
  }
  
  private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
    in.defaultReadObject();
    P = (ThermodynamicStateVariable) in.readObject();
    V = (ThermodynamicStateVariable) in.readObject();
    T = (ThermodynamicStateVariable) in.readObject();
  }
}